/************************************************************************/
/*		aPCI-8131 Device Driver for Windows 95/NT						*/
/*																		*/
/*			apci8131.h	-	Win32 interface definition					*/
/*			date		-	1999/08/23									*/
/************************************************************************/

#if !defined( APCI8131_H )
#define	APCI8131_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI8131_SUCCESS				0	/* Successfully proccessed */
#define	APCI8131_ERR_SYSTEM				1	/* Call GetLastError() */
#define	APCI8131_ERR_NO_DEVICE			2	/* No card */
#define	APCI8131_ERR_IN_USE				3	/* Device is in use */
#define	APCI8131_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	APCI8131_ERR_RESOURCE			5	/* Resource exhaustion */
#define	APCI8131_ERR_INVALID_PORT		6	/* Invalid port */
#define	APCI8131_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	APCI8131_ERR_NO_CREATE			8	/* No created device */

/*==========================================*/
/*	aPCI-8131 card's relative port address	*/
/*==========================================*/
#define	APCI8131_PORT_1	0
#define	APCI8131_PORT_2	1
#define	APCI8131_PORT_3	2
#define	APCI8131_PORT_4	3

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI8131_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI8131_MAX_PORTS	4			/* Maximum number of user ports */

										/* default search */
#define	APCI8131_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI8131_BOARD_ID	0x9031		/* pci bus device id */
#define	APCI8131_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI8131_DEVICE_ID	( ( DWORD )APCI8131_BOARD_ID\
							| ( ( DWORD )APCI8131_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI8131_MAX_MEM	9			/* number of memory windows */
#define	APCI8131_MAX_IO		20			/* number of i/o windows */
#define	APCI8131_MAX_IRQ	7			/* number of irqs */
#define	APCI8131_MAX_DMA	7			/* number of dmas */

typedef	struct	_APCI8131RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI8131_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI8131_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI8131_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI8131_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI8131_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[APCI8131_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[APCI8131_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI8131_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI8131_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI8131RESOURCE, *PAPCI8131R;

#if !defined( APCI8131_DRIVER )
#define	APCI8131_API

#if !defined( APCI8131_DLL )
	#define APCI8131LIB_API	extern __declspec( dllimport )
#else
	#define APCI8131LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI8131LIB_API BOOL	WINAPI	Apci8131GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI8131LIB_API BOOL	WINAPI	Apci8131Create( PWORD pwLogSlot );
APCI8131LIB_API BOOL	WINAPI	Apci8131Close( WORD wLogSlot );
APCI8131LIB_API BOOL	WINAPI	Apci8131GetResource( WORD wLogSlot, PAPCI8131R pres );
APCI8131LIB_API BOOL	WINAPI	Apci8131GetSwitchValue( WORD wLogSlot, PDWORD pdwSwitchValue );
APCI8131LIB_API BOOL	WINAPI	Apci8131InPort( WORD wLogSlot, DWORD dwLogPort, PBYTE pbInValue );
APCI8131LIB_API BOOL	WINAPI	Apci8131OutPort( WORD wLogSlot, DWORD dwLogPort, BYTE bOutValue );
APCI8131LIB_API DWORD	WINAPI	Apci8131GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI8131_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI8131_H ) */

/**/